/**
 * Based on examples in
 *     Head First Object-Oriented Analysis and Design
 *     by Brett D. McLaughlin, Gary Pollice, and David West
 *     O'Reilly, 2007
 *     ISBN 978-0-596-00867-3
 *
 * Ported from Java by
 *     Ronald Mak
 *     Department of Computer Engineering
 *     San Jose State University
 *     San Jose, CA  95192
 */
#ifndef GUITARSPEC_H_
#define GUITARSPEC_H_

#include <string>
#include "Builder.h"
#include "Type.h"
#include "Wood.h"

using namespace std;

class GuitarSpec
{
public:
    GuitarSpec(Builder builder, string model, Type type,
               Wood back_wood, Wood top_wood)
    : model(model), builder(builder), type(type),
      back_wood(back_wood), top_wood(top_wood)
    {}

    Builder get_builder() const   { return builder; }
    string  get_model() const     { return model; }
    Type    get_type() const      { return type; }
    Wood    get_back_wood() const { return back_wood; }
    Wood    get_top_wood() const  { return top_wood; }

private:
    string model;
    Builder builder;
    Type type;
    Wood back_wood, top_wood;
};

#endif /* GUITARSPEC_H_ */
