/**
 * Based on examples in
 *     Head First Object-Oriented Analysis and Design
 *     by Brett D. McLaughlin, Gary Pollice, and David West
 *     O'Reilly, 2007
 *     ISBN 978-0-596-00867-3
 *
 * Ported from Java by
 *     Ronald Mak
 *     Department of Computer Engineering
 *     San Jose State University
 *     San Jose, CA  95192
 */
#include <vector>
#include <algorithm>
#include "Inventory.h"
#include "Guitar.h"
#include "Builder.h"
#include "Type.h"
#include "Wood.h"

using namespace std;

void Inventory::add_guitar(string serial_number, double price,
                           Builder builder, string model, Type type,
                           Wood back_wood, Wood top_wood)
{
    Guitar *guitar = new Guitar(serial_number, price, builder,
                                model, type, back_wood, top_wood);
    guitars.push_back(guitar);
}

Guitar *Inventory::get_guitar(string serial_number) const
{
    for (Guitar *guitar : guitars)
    {
        if (guitar->get_serial_number() == serial_number) return guitar;
    }

    return nullptr;
}

vector<Guitar *> Inventory::search(GuitarSpec *ideal_spec)
{
    vector<Guitar *> matching_guitars;

    for (Guitar *guitar : guitars)
    {
        GuitarSpec *guitar_spec = guitar->get_spec();

        // Ignore serial number since that's unique.
        // Ignore price since that's unique.

        Builder builder = ideal_spec->get_builder();
        if (builder != guitar_spec->get_builder()) continue;

        string model = to_lower(ideal_spec->get_model());
        if (   (model != "")
            && (model != to_lower(guitar_spec->get_model()))) continue;

        Type type = ideal_spec->get_type();
        if (type != guitar_spec->get_type()) continue;

        Wood back_wood = ideal_spec->get_back_wood();
        if (back_wood!= guitar_spec->get_back_wood()) continue;

        Wood top_wood = ideal_spec->get_top_wood();
        if (top_wood != guitar_spec->get_top_wood()) continue;

        matching_guitars.push_back(guitar);
    }

    return matching_guitars;
}
